@@ -1,5 +1,6 @@
 use crate::args::PubArgs;
 use anyhow::Result;
+use futures::future::try_join_all;
 use pulsar::{Executor, producer, proto, Pulsar};
 
 pub async fn publish<RT: Executor>(pulsar: Pulsar<RT>, args: PubArgs) -> Result<()> {
@@ -17,6 +18,11 @@ pub async fn publish<RT: Executor>(pulsar: Pulsar<RT>, args: PubArgs) -> Result<
         .build()
         .await?;
 
-    producer.send(args.message).await?;
+    let mut fut_rcpts = vec![];
+    for _ in 0..args.repeat.unwrap_or(1) {
+        fut_rcpts.push(producer.send(args.message.clone()).await?);
+    }
+
+    try_join_all(fut_rcpts).await?;
     Ok(())
 }
\ No newline at end of file
